<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xalan="http://xml.apache.org/xslt"
                xmlns:common="org.enhydra.dods.Common"
                xmlns:dodst="org.enhydra.dods.xslt.DODSTag"
                     xmlns:miu="org.enhydra.dods.xslt.XSLTUtil"
                xmlns:stu="org.ejen.ext.StringUtil"
                version="1.0">
    <xsl:output method="text" encoding="utf-8"/>
<xsl:template name="fileHeader">
/*-----------------------------------------------------------------------------
 * Enhydra Java Application Server
 * Copyright 1997-2000 Lutris Technologies, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    This product includes Enhydra software developed by Lutris
 *    Technologies, Inc. and its contributors.
 * 4. Neither the name of Lutris Technologies nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY LUTRIS TECHNOLOGIES AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL LUTRIS TECHNOLOGIES OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *-----------------------------------------------------------------------------
 * <xsl:value-of select="PACKAGE"/>/<xsl:value-of select="CLASS_NAME"/>DataStruct.java
 *-----------------------------------------------------------------------------
 */

<xsl:value-of select="dodst:resetCounter()"/>
package <xsl:value-of select="translate(PACKAGE,'/','.')"/>;

import com.lutris.appserver.server.sql.*;
import java.sql.*;
import java.math.*;
import java.io.Serializable;
import com.lutris.dods.builder.generator.dataobject.*;
import com.lutris.dods.builder.generator.query.*;
import org.enhydra.dods.cache.Condition;


/**
 * Data structure for DO class.
 * A container for data members of a DO class.
 * A DO class contains a reference to a DataStruct class.  This reference
 * can be null (a DO whose data has not yet been retrieved from the database),
 * allowing a DO object to be a lightweight placeholder until its data is needed.
 *
 * @version $Revision: 1.2 $
 * @author  <xsl:value-of select="AUTHOR"/>
 * @since   <xsl:value-of select="PROJECT_NAME"/>;
 */
public class <xsl:value-of select="CLASS_NAME"/>DataStruct extends CoreDataStruct implements Cloneable, Serializable {

    /**
     * A DO refers to this DataStruct.
     * readOnly is set to true when the DO is stored in its class cache.
     */
    public boolean readOnly = false;

    /**
     * Since originalData is being constructed for every DO, this flag
     * "knows" if DataStruct has any useful content.
     */
    protected boolean isEmpty = true;

    /**
     * String identifying logical database this DataStruct belongs to.
     */
    private String databaseName = null;
    private String __the_handle;

    private byte[] copyByteArray( byte[] source ) {
        byte[] dest = new byte[ source.length ];
        System.arraycopy( source, 0, dest, 0, source.length );
        return dest;
    }

    /**
     * Returns DataStruct's version.    
     * @return DataStruct's version.    
     */
    protected int get_Version () {
        return super.get_Version();
    }

    /**
     * Sets DataStruct's version.
     * @param v new DataStruct's version.
     */
    protected void set_Version (int v) {
        super.set_Version(v);
    }

    /**
     * Sets this object's identifier.
     * @param oId this object's identifier.
     */
    protected void set_OId(ObjectId oId) {
    	super.set_OId(oId);
        __the_handle = oId.toString();
    }
    
<xsl:if test="DO_IS_OID_BASED='true'">
    /**
     * Returns this object's handle (identifier as a string).
     * @return This object's identifier as a string.
     *
     * @exception DatabaseManagerException
     *   If a connection to the database cannot be established, etc.
     */
    public String  get_Handle()
    throws DatabaseManagerException {
        if (null == __the_handle)
               throw new DatabaseManagerException("ID not set!");
        return __the_handle;
    }
    
    /**
     * Return <xsl:value-of select="TABLE_NAME"/> as the name of the table in the database
     * which contains <xsl:value-of select="CLASS_NAME"/>DataStruct objects.
     * This method overrides CoreDataStruct.getTableName().
     *
     * @return The database table name.
     *
     * /
    public String getTableName() {
        return &quot;<xsl:value-of select="TABLE_NAME"/>&quot;;
    }*/

    /**
     * Returns this object's cache handle (String in the form:
     * "&lt;database_name&gt;.&lt;indetifier_as_String&gt;").
     *
     * @return cache handle.
     * @exception DatabaseManagerException
     *   If a connection to the database cannot be established, etc.
     */
    public String  get_CacheHandle()throws DatabaseManagerException {
        return get_Database()+&quot;.<xsl:value-of select="TABLE_NAME"/>.&quot;+ get_Handle();
    }</xsl:if>

    /**
     * @param dbName - name of the logical database this DataStruct should belong to.
     */
    public void set_Database(String dbName) {
         if (null != databaseName)
             throw new Error("Whatta hack you are doing! Multiple db setting not allowed.");
         databaseName = dbName;
    }

    /**
     * @return name of the logical database this DataStruct belongs to.
     */
    public String get_Database() {
         return databaseName;
    }

    public CoreDataStruct dumpData(boolean incrementVersion) {
        <xsl:value-of select="CLASS_NAME"/>DataStruct ret =
            new <xsl:value-of select="CLASS_NAME"/>DataStruct();
        ret.set_OId(get_OId());
        ret.set_Version((incrementVersion?1:0)+get_Version());
        ret.set_Database(get_Database());
        return ret;
    }

    private Error newError(String column) {
        return new Error(&quot;This should never happen! &quot;
                         + column + &quot; on &quot; + this
                         + &quot; is being called although readOnly is true&quot;);
    }
	public void writeXMLData(java.io.Writer w) throws java.io.IOException {
		w.write(&quot;    &lt;wrs:currentRow>\n&quot;);
		w.write(&quot;      &lt;wrs:columnValue>&quot;+ get_OId() +&quot;&lt;/wrs:columnValue>\n&quot;);
		w.write(&quot;      &lt;wrs:columnValue>&quot;+ get_Version() +&quot;&lt;/wrs:columnValue>\n&quot;);
<xsl:for-each select="//COLUMN">		w.write(&quot;      &lt;wrs:columnValue>&quot;+ get<xsl:value-of select="common:capitalizeName(@name)"/>() +&quot;&lt;/wrs:columnValue>\n&quot;);
</xsl:for-each>		w.write(&quot;    &lt;/wrs:currentRow>\n&quot;);
	}
    static void writeXMLMetadata(java.io.Writer w) throws java.io.IOException {
		w.write(&quot;  &lt;wrs:metadata>\n&quot;);
		w.write(&quot;    &lt;wrs:column-count><xsl:value-of select="count(//COLUMN)+2" />&lt;/wrs:column-count>\n&quot;);
		w.write(&quot;    &lt;wrs:column-definition>\n&quot;);<xsl:value-of select="dodst:incCounter()"/>
		w.write(&quot;      &lt;wrs:column-index><xsl:value-of select="dodst:getCounter()" />&lt;/wrs:column-index>\n&quot;);
		w.write(&quot;      &lt;wrs:auto-increment>false&lt;/wrs:auto-increment>\n&quot;);
		w.write(&quot;      &lt;wrs:case-sensitive>false&lt;/wrs:case-sensitive>\n&quot;);
		w.write(&quot;      &lt;wrs:currency>false&lt;/wrs:currency>\n&quot;);
		w.write(&quot;      &lt;wrs:nullable>0&lt;/wrs:nullable>\n&quot;);
		w.write(&quot;      &lt;wrs:signed>true&lt;/wrs:signed>\n&quot;);
		w.write(&quot;      &lt;wrs:searchable>true&lt;/wrs:searchable>\n&quot;);
		w.write(&quot;      &lt;wrs:column-display-size>21&lt;/wrs:column-display-size>\n&quot;);
		w.write(&quot;      &lt;wrs:column-label>&quot;+ get_OIdColumnName() +&quot;&lt;/wrs:column-label>\n&quot;);
		w.write(&quot;      &lt;wrs:column-name>&quot;+ get_OIdColumnName() +&quot;&lt;/wrs:column-name>\n&quot;);
		w.write(&quot;      &lt;wrs:schema-name />\n&quot;);
		w.write(&quot;      &lt;wrs:column-precision>19&lt;/wrs:column-precision>\n&quot;);
		w.write(&quot;      &lt;wrs:column-scale>0&lt;/wrs:column-scale>\n&quot;);
		w.write(&quot;      &lt;wrs:table-name />\n&quot;);
		w.write(&quot;      &lt;wrs:catalog-name />\n&quot;);
		w.write(&quot;      &lt;wrs:column-type />\n&quot;);
		w.write(&quot;      &lt;wrs:column-type-name>DECIMAL&lt;/wrs:column-type-name>\n&quot;);
		w.write(&quot;    &lt;/wrs:column-definition>\n&quot;);
		w.write(&quot;    &lt;wrs:column-definition>\n&quot;);<xsl:value-of select="dodst:incCounter()"/>
		w.write(&quot;      &lt;wrs:column-index><xsl:value-of select="dodst:getCounter()" />&lt;/wrs:column-index>\n&quot;);
		w.write(&quot;      &lt;wrs:auto-increment>false&lt;/wrs:auto-increment>\n&quot;);
		w.write(&quot;      &lt;wrs:case-sensitive>false&lt;/wrs:case-sensitive>\n&quot;);
		w.write(&quot;      &lt;wrs:currency>false&lt;/wrs:currency>\n&quot;);
		w.write(&quot;      &lt;wrs:nullable>0&lt;/wrs:nullable>\n&quot;);
		w.write(&quot;      &lt;wrs:signed>true&lt;/wrs:signed>\n&quot;);
		w.write(&quot;      &lt;wrs:searchable>true&lt;/wrs:searchable>\n&quot;);
		w.write(&quot;      &lt;wrs:column-display-size>11&lt;/wrs:column-display-size>\n&quot;);
		w.write(&quot;      &lt;wrs:column-label>&quot;+ get_versionColumnName() +&quot;&lt;/wrs:column-label>\n&quot;);
		w.write(&quot;      &lt;wrs:column-name>&quot;+ get_versionColumnName() +&quot;&lt;/wrs:column-name>\n&quot;);
		w.write(&quot;      &lt;wrs:schema-name />\n&quot;);
		w.write(&quot;      &lt;wrs:column-precision>10&lt;/wrs:column-precision>\n&quot;);
		w.write(&quot;      &lt;wrs:column-scale>0&lt;/wrs:column-scale>\n&quot;);
		w.write(&quot;      &lt;wrs:table-name />\n&quot;);
		w.write(&quot;      &lt;wrs:catalog-name />\n&quot;);
		w.write(&quot;      &lt;wrs:column-type />\n&quot;);
		w.write(&quot;      &lt;wrs:column-type-name>int&lt;/wrs:column-type-name>\n&quot;);
		w.write(&quot;    &lt;/wrs:column-definition>\n&quot;);
<xsl:for-each select="//COLUMN"><xsl:call-template name="writeColumnDefinitions"/></xsl:for-each><xsl:value-of select="dodst:resetCounter()"/>		w.write(&quot;    &lt;/wrs:metadata>\n&quot;);
    }
</xsl:template>
<xsl:template name="writeColumnDefinitions"><xsl:value-of select="dodst:incCounter()"/>		w.write(&quot;    &lt;wrs:column-definition>\n&quot;);
		w.write(&quot;      &lt;wrs:column-index><xsl:value-of select="dodst:getCounter()" />&lt;/wrs:column-index>\n&quot;);
		w.write(&quot;      &lt;wrs:auto-increment>false&lt;/wrs:auto-increment>\n&quot;);
		w.write(&quot;      &lt;wrs:case-sensitive>false&lt;/wrs:case-sensitive>\n&quot;);
		w.write(&quot;      &lt;wrs:currency />\n&quot;);
		w.write(&quot;      &lt;wrs:nullable><xsl:value-of select="CAN_BE_NULL" />&lt;/wrs:nullable>\n&quot;);
		w.write(&quot;      &lt;wrs:signed />\n&quot;);
		w.write(&quot;      &lt;wrs:searchable><xsl:value-of select="USED_FOR_QUERY" />&lt;/wrs:searchable>\n&quot;);
		w.write(&quot;      &lt;wrs:column-display-size />\n&quot;);
		w.write(&quot;      &lt;wrs:column-label><xsl:value-of select="@name" />&lt;/wrs:column-label>\n&quot;);
		w.write(&quot;      &lt;wrs:column-name><xsl:value-of select="@name" />&lt;/wrs:column-name>\n&quot;);
		w.write(&quot;      &lt;wrs:schema-name />\n&quot;);
		w.write(&quot;      &lt;wrs:column-precision />\n&quot;);
		w.write(&quot;      &lt;wrs:column-scale />\n&quot;);
		w.write(&quot;      &lt;wrs:table-name />\n&quot;);
		w.write(&quot;      &lt;wrs:catalog-name />\n&quot;);
		w.write(&quot;      &lt;wrs:column-type />\n&quot;);
		w.write(&quot;      &lt;wrs:column-type-name><xsl:value-of select="DB_TYPE" />&lt;/wrs:column-type-name>\n&quot;);
		w.write(&quot;    &lt;/wrs:column-definition>\n&quot;);
</xsl:template>
</xsl:stylesheet>
