package jtaDiscRack.presentation.dpanels;

import jtaDiscRack.presentation.delements.*;

import javax.swing.*;
import javax.swing.border.*;

import java.awt.*;

/**
 * Base class for all panels that manage data of elements.
 *
 * @author Sasa Bojanic
 * @version 1.0
 */
public class DPanel extends JPanel {
   public static final Dimension textFieldDimension=new Dimension(200,20);
   public static final Dimension tableDimension=new Dimension(700,375);


   private DSimpleElement myOwner;
   private String title;

   public DPanel () {
      super();
   }

   public DPanel (DSimpleElement myOwner,int noOfElements,String title,
      boolean isVertical,boolean hasBorder) {

      super();

      this.myOwner=myOwner;

      setTitle(title,hasBorder);

      setLayout(new BoxLayout(this,((isVertical) ? BoxLayout.Y_AXIS:BoxLayout.X_AXIS)));
      setAlignmentX(Component.LEFT_ALIGNMENT);
      setAlignmentY(Component.TOP_ALIGNMENT);

      if (myOwner!=null) {
         setEnabled(!myOwner.isReadOnly());
      }

   }

   public void setTitle (String title,boolean hasBorder) {
      this.title=title;

      int emptyBorderHSize=10;
      int emptyBorderVSize=10;
      if (!hasBorder) {
         emptyBorderVSize=1;
      }
      Border emptyb=BorderFactory.createEmptyBorder(emptyBorderVSize,emptyBorderHSize,
         emptyBorderVSize,emptyBorderHSize);
      Border inb=BorderFactory.createEmptyBorder(0,0,0,0);
      if (hasBorder) {
         inb=BorderFactory.createMatteBorder(1,1,1,1,Color.darkGray);
         inb=BorderFactory.createTitledBorder(inb,title);
      }
      else {
         emptyb=BorderFactory.createTitledBorder(emptyb,title);
      }
      setBorder(BorderFactory.createCompoundBorder(emptyb,inb));
   }

   public static void defaultErrorMessage (Window w,String elementTitle) {
      String message="The value must be defined, define it or press Cancel !!!";
      String dialogTitle="Value is not defined";

      DPanel.errorMessage(w,dialogTitle,elementTitle,message);
   }

   public static void errorMessage (Window w,String dialogTitle,String elementTitle,String message) {
      JOptionPane.showMessageDialog(w,elementTitle+message,
         dialogTitle,JOptionPane.ERROR_MESSAGE);
   }

   public DSimpleElement getOwner () {
      return myOwner;
   }

   public String getTitle() {
      return title;
   }

   /**
   * Checks if the element that owns panel
   */
   public boolean checkRequired () {
      return true;
   }

   // Always returns true, this is set because of panels that are never empty
   // but this method is used when checking emptiness of group panel,
   // and panels that do not override this method should not be ever considered
   public boolean isEmpty () {
      return true;
   }

   public void setElements () {
      return;
   }

   /**
   * Find the hosting window.
   */
   public Window getWindow () {
      for (Container p = getParent(); p != null; p = p.getParent()) {
         if (p instanceof Window) {
            return (Window)p;
         }
      }
      return null;
   }

}
