package discRack.presentation;

import discRack.presentation.delements.*;
import discRack.presentation.dpanels.*;
import org.enhydra.dods.exceptions.AssertionDataObjectException;
import discRack.business.disc.*;

import java.util.*;
import java.io.*;
import javax.swing.*;

/**
 * Used to manage Disc DO data.
 *
 * @author Sasa Bojanic
 * @version 1.0
 */
public class Disc extends DCollectionElement {
   private DSimpleElement refTitle=new DSimpleElement("Title");
   private DSimpleElement refArtist=new DSimpleElement("Artist");
   private DSimpleElement refGenre=new DSimpleElement("Genre");
   private DSimpleElement refIsLiked=new DSimpleElement("Is Liked",true);

   private discRack.business.disc.Disc myDisc;

   public Disc (Discs discs,discRack.business.disc.Disc d) {
      super("Disc",discs);
      myDisc=d;
      fillData();
      fillStructure();
   }

   protected void fillStructure () {
      super.fillStructure();
      refTitle.setRequired(true);
      refArtist.setRequired(true);
      complexStructure.add(refTitle);
      complexStructure.add(refArtist);
      complexStructure.add(refGenre);
      complexStructure.add(refIsLiked);
   }

   private void fillData () {
      try {
         attrId.setValue(myDisc.getHandle());
         refTitle.setValue(myDisc.getTitle());
         refArtist.setValue(myDisc.getArtist());
         refGenre.setValue(myDisc.getGenre());
         refIsLiked.setValue(new Boolean(myDisc.isLiked()));
      } catch (Exception ex) {}
   }

   /**
     * This method is called only if user doesn't press Cancel button within
     * the dialog for editing properties, so the changes are applied here.
     * @param groupPanel The panel for editing parameters.
     * @return always returns <tt>true</tt>.
     */
   public boolean setDODSElements (DPanel p) {
       DGroupPanel dgp=(DGroupPanel)p;
       DTextPanel idtp=(DTextPanel)dgp.getPanel(0);
       DTextPanel ttp=(DTextPanel)dgp.getPanel(1);
       DTextPanel atp=(DTextPanel)dgp.getPanel(2);
       DTextPanel gtp=(DTextPanel)dgp.getPanel(3);
       DCheckPanel ilcp=(DCheckPanel)dgp.getPanel(4);

       String title=ttp.getText();
       String artist=atp.getText();
       String genre=gtp.getText();

       boolean isLiked=ilcp.getCheckBox().isSelected();

       try {
		  discRack.business.disc.Disc tempDisc = DiscFactory.findDiscByID(myDisc.getHandle()); 
		  if (!tempDisc.isDONull() && (tempDisc.getVersion()!=myDisc.getVersion())){
			  JOptionPane.showMessageDialog(p.getWindow(),
			  "Data are allredy changed by another user.","Disc error",
			  JOptionPane.ERROR_MESSAGE);
			  return false;
		  }else{       	
          myDisc.setTitle(title);
          myDisc.setArtist(artist);
          myDisc.setGenre(genre);
          myDisc.setLiked(isLiked);
          myDisc.save();
          return true;
      	 }
       } catch (AssertionDataObjectException ex) {
          JOptionPane.showMessageDialog(p.getWindow(),
                "Read-only cache: DML opertions not allowed.","Disc error",
                JOptionPane.ERROR_MESSAGE);
          return false;
       } catch (Exception ex) {
          JOptionPane.showMessageDialog(p.getWindow(),
                "Something went wrong, please try again !","Disc error",
                JOptionPane.ERROR_MESSAGE);
          return false;
       }
    }

    public discRack.business.disc.Disc getMyDisc () {
       return myDisc;
    }
}
